Learn R Programming

LAGOSNE (version 1.2.0)

LAGOSNE-deprecated: Deprecated functions in the LAGOSNE package

Description

These functions are provided for compatibility with older versions of the LAGOSNE package. They may eventually be completely removed.

Usage

lagos_get(...)

Arguments

...

Parameters to be passed to the modern version of the function

Details

lagos_get now a synonym for lagosne_get
lagos_load now a synonym for lagosne_load
lagos_select now a synonym for lagosne_select
lagos_compile now a synonym for lagosne_compile