A dataset containing Secchi disk measurements from lakes.
A data frame with 913319 observations of 12 variables:
eventida1087: unique combination of programid, lakeid, and date for each sampling event
lagoslakeid: unique LAGOSNE lake identifier
programname: name of the sampling/monitoring program that collected the data
programtype: categorical description of the type of sampling /monitoring effort
lagosversion: current version of LAGOSNE that the data record belongs to
sampledate: date at which the sample was collected, stored in date format (YYYY-MM-DD)
secchi: Secchi depth in meters
secchi_censorcode: identifies whether a Secchi value is censored and the censor type
secchi_qual: data flags from the source program
secchi_methodinfo: flag to indicate variables that were sampled using different methods. "SECCHI_VIEW" = viewing box used to measure Secchi depth, "SECCHI_VIEW_UNKNOWN" = unknown whether viewing box was used, "NA" = no viewing box used to measure Secchi depth.
sampleyear: year (4-digit) of sampling event
samplemonth: month (1 through 12) of sampling event
There is some overlap between the Secchi values reported in table 'secchi' and table 'epi_nutr'. The 'epi_nutr' table only contains Secchi observations when there were additional nutrient data collected at the same time.
Soranno et al. (2015) Gigascience 4:28